====
init
====

.. automodule:: cmkinitramfs.init
   :platform: Linux

.. autoclass:: Breakpoint
   :members:
   :show-inheritance:

.. autofunction:: _fun_rescue_shell

.. autofunction:: _fun_panic

.. autofunction:: _fun_die

.. autofunction:: _fun_log

.. autofunction:: do_header

.. autofunction:: do_init

.. autofunction:: do_cmdline

.. autofunction:: do_keymap

.. autofunction:: do_module

.. autofunction:: do_break

.. autofunction:: do_switch_root

.. autofunction:: mkinit

